#!/usr/bin/python3
#

from array import array
from collections import deque
import itertools
import sys

debug = False

class Slot:

    def __init__(self, kind, D, H, M, T, Dn, Kn):
        self.kind = kind
        self.day = D
        self.start = H * 60 + M
        self.end = self.start + Dn * 60
        self.teacher = T
        self.capacity = Kn
        self.compatibles = set()

    def check_compatible(self, other):
        if self.day != other.day or \
                self.start >= other.end + 5 or self.end + 5 <= other.start:
                    self.compatibles.add(other)

    def compatible(self, other):
        return other in self.compatibles

    def __repr__(self):
        return "{}(day {}, {}:{:02}-{}:{:02}, teacher {}, capacity {})" \
               .format(self.kind, self.day,
                       self.start // 60, self.start % 60, self.end // 60, self.end % 60,
                       self.teacher, self.capacity)

def edmondskarp(residual, n1, n2, goal, expl, comp):
    total = n1 + n2 + 2
    source = 0
    sink = total - 1
    total_cap = 0
    parents = array('i', (-1 for _ in range(total)))
    parents_init = parents[:]
    cap = array('i', (0 for _ in range(total)))
    cap[source] = 999999
    to_see = deque([source])
    while to_see and total_cap < goal:
        node = to_see.popleft()
        for other in comp[node]:
            if other != node and other != source and parents[other] == -1 and residual[node*total+other] > 0:
                parents[other] = node
                c, r = cap[node], residual[node*total+other]
                cap[other] = c if c < r else r
                if other == sink:
                    path_cap = cap[other]
                    l = [other]
                    while parents[other] != -1:
                        p = parents[other]
                        l.append(p)
                        residual[p*total+other] -= path_cap
                        residual[other*total+p] += path_cap
                        other = p
                    total_cap += path_cap
                    if debug:
                        print("path_cap = {}, path = {}".format(path_cap, [expl[x] for x in l]))
                    to_see = deque([source])
                    parents = parents_init[:]
                    break
                else:
                    to_see.insert(0, other)
    if debug:
        print("Total capacity found: {} (goal was {})".format(total_cap, goal))
    return total_cap, residual

def problem():
    S = int(sys.stdin.readline())
    (N1, K1, D1, T1) = [int(i) for i in sys.stdin.readline().split()]
    FC = [Slot("FC", *[int(i) for i in sys.stdin.readline().split()], D1, K1) for _ in range(N1)]
    (N2, K2, D2, T2) = [int(i) for i in sys.stdin.readline().split()]
    IC = [Slot("IC", *[int(i) for i in sys.stdin.readline().split()], D2, K2) for _ in range(N2)]
    C = int(sys.stdin.readline())
    conflicts = set(tuple(int(i) for i in sys.stdin.readline().split()) for _ in range(C))
    gmask = set(x.day for x in FC + IC)
    for f in FC:
        for i in IC:
            if (f.teacher, i.teacher) not in conflicts:
                f.check_compatible(i)
    max_total = N1 + N2 + 2
    zeroes = array('i', (0 for _ in range(max_total * max_total)))
    for number_of_days in range(1, 7):
        for d in itertools.combinations(gmask, number_of_days):
            if debug:
                print("Checking days {}".format(d))
            fc = [c for c in FC if c.day in d]
            ic = [c for c in IC if c.day in d]
            n1 = len(fc)
            n2 = len(ic)
            total = 1 + n1 + n2 + 1 # Source + FCs + ICs + Sink
            capacities = zeroes[:total*total]
            comp = [[] for _ in range(n1+n2+2)]
            comp[0] = list(range(1, n1+1))
            for i in range(n1):
                for j in range(n2):
                    if fc[i].compatible(ic[j]):
                        capacities[(i+1)*total+j+1+n1] = S
                        comp[i+1].append(1+n1+j)
                        comp[1+n1+j].append(i+1)
            for i in range(n1):
                capacities[0*total+i+1] = fc[i].capacity
            for j in range(n2):
                capacities[(j+1+n1)*total+total-1] = ic[j].capacity
                comp[1+n1+j].append(1+n1+n2)
            expl = ["source"] + fc + ic + ["sink"]
            total_cap, residual = edmondskarp(capacities[:], n1, n2, S, expl, comp)
            if total_cap >= S:
                if debug:
                    print("Solution found (for {} capacity >= {} students):".format(total_cap, S))
                    for i in range(n1):
                        for j in range(n2):
                            index = (1 + i) * total + (n1 + 1 + j)
                            f = capacities[index] - residual[index]
                            if f > 0:
                                print("  - {} between {} and {}".format(f, fc[i], ic[j]))
                print(number_of_days)
                sys.exit(0)
    print(0)

if __name__ == '__main__':
    if sys.argv[1:2] == ["-d"]:
        debug = True
    problem()
